import { login, logout, getInfo } from '@/api/user'
import { getToken, setToken, removeToken } from '@/utils/auth'
import { resetRouter } from '@/router'

function getDefaultState() {
  return {
    token: getToken(),
    name: '',
    avatar: ''
  }
}

export default {
  state: getDefaultState(),
  login: function(userInfo) {
    const { username, password } = userInfo
    return new Promise((resolve, reject) => {
      login({ username: username.trim(), password: password }).then(response => {
        const { data } = response
        this.state.token = data.token
        setToken(data.token)
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  },
  getInfo() {
    return new Promise((resolve, reject) => {
      getInfo(this.state.token).then(response => {
        const { data } = response

        if (!data) {
          return reject('Verification failed, please Login again.')
        }

        const { name, avatar } = data
        this.state.name = name
        this.state.avatar = avatar
        resolve(data)
      }).catch(error => {
        reject(error)
      })
    })
  },
  logout() {
    return new Promise((resolve, reject) => {
      logout(this.state.token).then(() => {
        removeToken() // must remove  token  first
        resetRouter()
        Object.assign(this.state, getDefaultState())
        resolve()
      }).catch(error => {
        reject(error)
      })
    })
  },
  // remove token
  resetToken() {
    return new Promise(resolve => {
      removeToken() // must remove  token  first
      Object.assign(this.state, getDefaultState())
      resolve()
    })
  }
}

